@@ -13,10 +13,6 @@ void
 on_menubar1_unrealize                  (GtkWidget       *widget,
                                         gpointer         user_data);
 
-void
-on_new2_activate                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_open_criteria1_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -109,10 +105,6 @@ void
 on_stopButton_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_one_phase_searching1_activate       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_configuration1_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -141,10 +133,6 @@ void
 on_about1_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_saveResults_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_playButton_clicked                  (GtkButton       *button,
                                         gpointer         user_data);
@@ -153,10 +141,6 @@ void
 on_stopButton_clicked                  (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_printResult_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_Question_clicked                    (GtkButton       *button,
                                         gpointer         user_data);
@@ -197,18 +181,6 @@ void
 on_expertUserCheck_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_expertUserCheck_unrealize           (GtkWidget       *widget,
-                                        gpointer         user_data);
-
-void
-on_expertUserCheck_realize             (GtkWidget       *widget,
-                                        gpointer         user_data);
-
-void
-on_playButton1_activate                (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_treeview1_realize                   (GtkWidget       *widget,
                                         gpointer         user_data);
@@ -358,10 +330,6 @@ on_midTreeView_drag_end                (GtkWidget       *widget,
                                         GdkDragContext  *drag_context,
                                         gpointer         user_data);
 
-void
-on_multiFolderSelector_clicked         (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_notebook2_switch_page               (GtkNotebook     *notebook,
                                         GtkNotebookPage *page,
@@ -396,18 +364,6 @@ void
 on_forums1_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_newWindow_clicked                   (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_importCriteria_clicked              (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_exportCriteria_clicked              (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_matches1_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -424,18 +380,6 @@ void
 on_autoAdjustColumnWidth_toggled       (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_configResultEOL_changed             (GtkEditable     *editable,
-                                        gpointer         user_data);
-
-void
-on_configResultEOF_changed             (GtkEditable     *editable,
-                                        gpointer         user_data);
-
-void
-on_configResultDelimiter_changed       (GtkEditable     *editable,
-                                        gpointer         user_data);
-
 gboolean
 on_configResultEOL_focus_out_event     (GtkWidget       *widget,
                                         GdkEventFocus   *event,
@@ -451,3 +395,158 @@ on_configResultDelimiter_focus_out_event
                                         (GtkWidget       *widget,
                                         GdkEventFocus   *event,
                                         gpointer         user_data);
+
+void
+on_newInstance1_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_horizontal_results1_activate        (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_vertical_results1_activate          (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_importCriteria_clicked              (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_exportCriteria_clicked              (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_saveResults_clicked                 (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_printResults_clicked                (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_newInstance2_clicked                (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_playButton2_clicked                 (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_stopButton2_clicked                 (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_aboutSearchmonkey_response          (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+void
+on_autosize_columns_activate           (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_edit_file1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_open_folder1_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_containingText_changed              (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_searchNotebook_switch_page          (GtkNotebook     *notebook,
+                                        GtkNotebookPage *page,
+                                        guint            page_num,
+                                        gpointer         user_data);
+
+void
+on_basic_mode1_toggled                 (GtkCheckMenuItem *checkmenuitem,
+                                        gpointer         user_data);
+
+void
+on_expert_mode1_toggled                (GtkCheckMenuItem *checkmenuitem,
+                                        gpointer         user_data);
+
+void
+on_folderDepthCheck_toggled            (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_searchSubfoldersCheck_toggled       (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_dosExpressionRadioFile_activate     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_regularExpressionRadioFile_activate (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dosExpressionRadioFile_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_regularExpressionRadioFile_clicked  (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_afterCalenderBtn_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_beforeCalendatBtn_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_regexp_focus_out_event              (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+gboolean
+on_regexp_focus_out_event              (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+gboolean
+on_regexp_focus_out_event              (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+gboolean
+on_fileName_focus                      (GtkWidget       *widget,
+                                        GtkDirectionType  direction,
+                                        gpointer         user_data);
+
+gboolean
+on_regexp2_focus_out_event             (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+void
+on_limitResultsCheckResults_toggled    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_showLinesCheckResults_toggled       (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+gboolean
+on_searchNotebook_focus_out_event      (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+void
+on_limitContentsCheckResults_toggled   (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_autoComplete_response               (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
